@@ -8,7 +8,9 @@ markdownMap = {
     u"MESSAGE": u"message",
     u"ENV": u"env",
     u"PLATFORM": u"platform",
-		u"LEVEL": u'level'
+    u"DATETIME": u"datetime",
+		u"LEVEL": u'level',
+		u"RELEASE": u'release'
 }
 
 defaultMarkdown = u'''
@@ -23,8 +25,11 @@ def formatTemplate(detail, template=defaultMarkdown):
 	template = template.format(
 		PROJECT_NAME=detail.get('PROJECT_NAME'),
 		TITLE=detail.get('title'),
-		MESSAGE=detail.get('logentry').formatted,
+		MESSAGE=detail.message,
 		URL=detail.get('URL'),
 		ENV=detail.get('environment'),
-		PLATFORM=detail.get('platform'))
+		PLATFORM=detail.get('platform'),
+		DATETIME=detail.get('datetime'),
+		RELEASE=detail.get('release'),
+	)
 	return template
